# Zurich Instruments drivers for QCoDeS (zhinst-qcodes)
The Zurich Instruments drivers for QCoDeS (zhinst-qcodes) are a package of instrument drivers for devices produced by [Zurich Instruments](https://www.zhinst.com) for QCoDeS. [QCoDeS](http://qcodes.github.io/Qcodes) is a Python-based data acquisition framework developed to serve the needs of nanoelectronic device experiments, but not limited to that. It is intended to be used within QCoDeS and not as standalone package. The QCoDeS instrument drivers are based on the [Zurich Instruments Toolkit](https://github.com/zhinst/zhinst-toolkit).

## Status
The zhinst-qcodes is well tested and considered stable enough for general usage. The interfaces may have some incompatible changes between releases. Please check the changelog if you are upgrading.

## Install

Install the package with pip:

```
pip install zhinst-qcodes
```

See [INSTALL](INSTALL.md) for more information.

## Documentation
See the documentation page [here](https://docs.zhinst.com/zhinst-qcodes/en/latest).

## Contributing
We welcome contributions by the community, either as bug reports, fixes and new code. Please use the GitHub issue tracker to report bugs or submit patches. Before developing something new, please get in contact with us. 

## License
This software is licensed under the terms of the MIT license. See [LICENSE](LICENSE) for more detail.


